/// <reference types="passport" />
import { Strategy } from 'passport-strategy';
import * as passport from 'passport';
import * as exegesis from 'exegesis';
export declare type PassportToExegesisResult = (Pick<exegesis.AuthenticationSuccess, 'user' | 'roles' | 'scopes'>) | {
    [prop: string]: any;
};
export interface PassportToExegesisRolesFn {
    (user: any, pluginContext: exegesis.ExegesisPluginContext): PassportToExegesisResult;
}
/**
 * Create a new Exegesis authenticator from a passport instance.
 *
 * @param passport - The passport instance to call into.  This should be installed
 *   in your middleware chain before exegesis with `app.use(passport.initialize())`.
 * @param strategyName - The name of the passport strategy to use.  This strategy
 *   should be registered with passport with `passport.use(...)`.
 * @param converter - A function to convert Passport users into
 *   `{user, roles, scopes}` objects.  If not defined, `user.roles` will be used
 *   as roles, and `user.scopes` will be used as scopes.
 * @returns - An Exegesis authenticator.
 */
export declare function exegesisPassport(passport: passport.Authenticator, strategyName: string, converter?: PassportToExegesisRolesFn): exegesis.Authenticator;
/**
 * Create a new Exegesis authenticator from a passport strategy.
 *
 * @param strategy - An instance of a Passport strategy to call.  Passport
 *   does not need to be registered as a middleware for this to work.
 * @param converter - A function to convert Passport users into
 *   `{user, roles, scopes}` objects.  If not defined, `user.roles` will be used
 *   as roles, and `user.scopes` will be used as scopes.
 * @returns - An Exegesis authenticator.
 */
export declare function exegesisPassport(strategy: Strategy, converter?: PassportToExegesisRolesFn): exegesis.Authenticator;
export default exegesisPassport;
